import { jsx, Fragment } from 'react/jsx-runtime';
import { datadogRum } from '@datadog/browser-rum';
import { useEffect } from 'react';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __read(o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
}

function __spreadArray(to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
}

var DEFAULT_SAMPLE_RATE = 100;

function useDataDog(_a) {
    var actionNameAttribute = _a.actionNameAttribute, allowedTracingOrigins = _a.allowedTracingOrigins, applicationId = _a.applicationId, beforeSend = _a.beforeSend, clientToken = _a.clientToken, defaultPrivacyLevel = _a.defaultPrivacyLevel, enableExperimentalFeatures = _a.enableExperimentalFeatures, env = _a.env, intakeApiVersion = _a.intakeApiVersion, internalMonitoringApiKey = _a.internalMonitoringApiKey, proxyUrl = _a.proxyUrl, replaySampleRate = _a.replaySampleRate, replica = _a.replica, _b = _a.sampleRate, sampleRate = _b === void 0 ? DEFAULT_SAMPLE_RATE : _b, service = _a.service, _c = _a.sessionReplayRecording, sessionReplayRecording = _c === void 0 ? true : _c, silentMultipleInit = _a.silentMultipleInit, _d = _a.site, site = _d === void 0 ? 'datadoghq.com' : _d, _e = _a.trackInteractions, trackInteractions = _e === void 0 ? true : _e, trackSessionAcrossSubdomains = _a.trackSessionAcrossSubdomains, trackViewsManually = _a.trackViewsManually, useAlternateIntakeDomains = _a.useAlternateIntakeDomains, useCrossSiteSessionCookie = _a.useCrossSiteSessionCookie, useSecureSessionCookie = _a.useSecureSessionCookie, version = _a.version;
    useEffect(function () {
        var getAllowedTracingOrigins = function () {
            if (typeof allowedTracingOrigins === 'undefined') {
                return;
            }
            return __spreadArray([], __read(allowedTracingOrigins), false);
        };
        var getEnableExperimentalFeatures = function () {
            if (typeof enableExperimentalFeatures === 'undefined') {
                return;
            }
            return __spreadArray([], __read(enableExperimentalFeatures), false);
        };
        datadogRum.init({
            actionNameAttribute: actionNameAttribute,
            allowedTracingOrigins: getAllowedTracingOrigins(),
            applicationId: applicationId,
            beforeSend: beforeSend,
            clientToken: clientToken,
            defaultPrivacyLevel: defaultPrivacyLevel,
            enableExperimentalFeatures: getEnableExperimentalFeatures(),
            env: env,
            intakeApiVersion: intakeApiVersion,
            internalMonitoringApiKey: internalMonitoringApiKey,
            proxyUrl: proxyUrl,
            replaySampleRate: replaySampleRate,
            replica: replica,
            sampleRate: sampleRate,
            service: service,
            silentMultipleInit: silentMultipleInit,
            site: site,
            trackInteractions: trackInteractions,
            trackSessionAcrossSubdomains: trackSessionAcrossSubdomains,
            trackViewsManually: trackViewsManually,
            useAlternateIntakeDomains: useAlternateIntakeDomains,
            useCrossSiteSessionCookie: useCrossSiteSessionCookie,
            useSecureSessionCookie: useSecureSessionCookie,
            version: version,
        });
    }, [
        actionNameAttribute,
        allowedTracingOrigins,
        applicationId,
        beforeSend,
        clientToken,
        defaultPrivacyLevel,
        enableExperimentalFeatures,
        env,
        intakeApiVersion,
        internalMonitoringApiKey,
        proxyUrl,
        replaySampleRate,
        replica,
        sampleRate,
        service,
        silentMultipleInit,
        site,
        trackInteractions,
        trackSessionAcrossSubdomains,
        trackViewsManually,
        useAlternateIntakeDomains,
        useCrossSiteSessionCookie,
        useSecureSessionCookie,
        version,
    ]);
    useEffect(function () {
        if (!sessionReplayRecording) {
            return;
        }
        datadogRum.startSessionReplayRecording();
        return function () {
            datadogRum.stopSessionReplayRecording();
        };
    }, [sessionReplayRecording]);
}

function DataDog(_a) {
    var actionNameAttribute = _a.actionNameAttribute, allowedTracingOrigins = _a.allowedTracingOrigins, applicationId = _a.applicationId, beforeSend = _a.beforeSend, children = _a.children, clientToken = _a.clientToken, defaultPrivacyLevel = _a.defaultPrivacyLevel, enableExperimentalFeatures = _a.enableExperimentalFeatures, env = _a.env, intakeApiVersion = _a.intakeApiVersion, internalMonitoringApiKey = _a.internalMonitoringApiKey, proxyUrl = _a.proxyUrl, replaySampleRate = _a.replaySampleRate, replica = _a.replica, sampleRate = _a.sampleRate, service = _a.service, sessionReplayRecording = _a.sessionReplayRecording, silentMultipleInit = _a.silentMultipleInit, site = _a.site, trackInteractions = _a.trackInteractions, trackSessionAcrossSubdomains = _a.trackSessionAcrossSubdomains, trackViewsManually = _a.trackViewsManually, useAlternateIntakeDomains = _a.useAlternateIntakeDomains, useCrossSiteSessionCookie = _a.useCrossSiteSessionCookie, useSecureSessionCookie = _a.useSecureSessionCookie, version = _a.version;
    useDataDog({
        actionNameAttribute: actionNameAttribute,
        allowedTracingOrigins: allowedTracingOrigins,
        applicationId: applicationId,
        beforeSend: beforeSend,
        clientToken: clientToken,
        defaultPrivacyLevel: defaultPrivacyLevel,
        enableExperimentalFeatures: enableExperimentalFeatures,
        env: env,
        intakeApiVersion: intakeApiVersion,
        internalMonitoringApiKey: internalMonitoringApiKey,
        proxyUrl: proxyUrl,
        replaySampleRate: replaySampleRate,
        replica: replica,
        sampleRate: sampleRate,
        service: service,
        sessionReplayRecording: sessionReplayRecording,
        silentMultipleInit: silentMultipleInit,
        site: site,
        trackInteractions: trackInteractions,
        trackSessionAcrossSubdomains: trackSessionAcrossSubdomains,
        trackViewsManually: trackViewsManually,
        useAlternateIntakeDomains: useAlternateIntakeDomains,
        useCrossSiteSessionCookie: useCrossSiteSessionCookie,
        useSecureSessionCookie: useSecureSessionCookie,
        version: version,
    });
    return jsx(Fragment, { children: children }, void 0);
}

function DataDogPrivacy(_a) {
    var children = _a.children, level = _a.level;
    return (jsx("span", __assign({ className: "dd-privacy-" + level, "data-dd-privacy": level }, { children: children }), void 0));
}

function DataDogAllow(_a) {
    var children = _a.children;
    return jsx(DataDogPrivacy, __assign({ level: "allow" }, { children: children }), void 0);
}

function DataDogHidden(_a) {
    var children = _a.children;
    return jsx(DataDogPrivacy, __assign({ level: "hidden" }, { children: children }), void 0);
}

function DataDogMask(_a) {
    var children = _a.children;
    return jsx(DataDogPrivacy, __assign({ level: "mask" }, { children: children }), void 0);
}

function DataDogMaskUserInput(_a) {
    var children = _a.children;
    return jsx(DataDogPrivacy, __assign({ level: "mask-user-input" }, { children: children }), void 0);
}

function useDataDogRum() {
    return datadogRum;
}

export { DataDogAllow, DataDogHidden, DataDogMask, DataDogMaskUserInput, DataDog as default, useDataDogRum };
